#!/usr/bin/env perl
use strict;
use warnings;

use Test::More tests => 6;
use Test::NoWarnings;
use Data::Dump 'pp';

BEGIN { use_ok('List::Index'); }
ok(eval { List::Index->VERSION(1) }, 'version 1.00 compatibility');

subtest 'single-char alphabet' => sub {
	plan tests => 4;
	my @uniform = 'a'..'z';
	my $index = List::Index->new(\@uniform) or return;
	is_deeply(\@uniform, ['a'..'z'], 'original data unaltered');
	is_deeply($index->ranges, ['-'], 'single page');
	is_deeply($index->ranges({pages => 3}), [qw(-i j-q r-)], 'given pages');
	is_deeply($index->ranges({pagesize => @uniform / 2.1}), [qw(
		-i j-q r-
	)], 'equivalent pagesize');
};

subtest 'uniform alphanumeric' => sub {
	plan tests => 2;
	my $index = List::Index->new(['aa'..'zz', 1..202]) or return;
	is_deeply($index->ranges, [qw(
		-.
		.-bp bq-dm dn-fi fj-hf hg-i j-k l-m n-os ot-qp qq-sm sn-uj uk-wf wg-x y-

	)], 'default ranges');
	is_deeply($index->ranges({pagesize => 300}), [qw(-c d-n o-)], 'large pagesize');
};

subtest 'context' => sub {
	plan tests => 4;
	my $index = List::Index->new([qw(
		baa1 baa2  baa3 baaa  bbc cbc  daaa ea  eaaa zed
	)]) or return;
	is_deeply($index->ranges({pagesize => 2, context => 0}), [
		qw(-baa. baa.-bbb bbc-daa. daaa-eaa. eaaa-)
	], 'no context');
	is_deeply($index->ranges({pagesize => 2}), [
		qw(-a b c d e-)
	], 'default context');  # context should be 1
	is_deeply($index->ranges({pagesize => 2, context => 2}), [
		qw(-a b-c d e-)
	], 'overlap');  # first item equals second due to large context
	is_deeply($index->ranges({pagesize => 2, context => 0, length => 1}), [
		qw(-a b-c d e-)
	], 'single char');

	#pp($index->ranges({pagesize => 2, context => 2, length => 1}));
};

